@@ -16,7 +16,7 @@ log = logging.getLogger("qds")
 usage_str = ("Usage: \n"
              "qds [options] <CmdArgs | hadoop_cluster check>\n"
              "\nCmdArgs:\n" +
-             "  <hivecmd|hadoopcmd|pigcmd|shellcmd> <submit|run|check|cancel> [args .. ]\n"
+             "  <hivecmd|hadoopcmd|pigcmd|shellcmd|dbexportcmd> <submit|run|check|cancel> [args .. ]\n"
              "  submit [cmd-specific-args .. ] : submit cmd & print id \n"
              "  run [cmd-specific-args .. ] : submit cmd & wait. print results \n"
              "  check <id> : print the cmd object for this Id\n"
@@ -152,6 +152,10 @@ def main():
                          default=os.getenv('QDS_POLL_INTERVAL'),
                          help="interval for polling API for completion and other events. defaults to 5s")
 
+    optparser.add_option("--skip_ssl_cert_check", dest="skip_ssl_cert_check", action="store_true",
+                         default=False,
+                         help="skip verification of server SSL certificate. Insecure: use with caution.")
+
     optparser.add_option("-v", dest="verbose", action="store_true",
                          default=False,
                          help="verbose mode - info level logging")
@@ -185,11 +189,16 @@ def main():
     if options.poll_interval is None:
         options.poll_interval = 5;
 
+    if options.skip_ssl_cert_check is None:
+        options.skip_ssl_cert_check = False
+    elif options.skip_ssl_cert_check:
+        sys.stderr.write("[WARN] Insecure mode enabled: skipping SSL cert verification\n")
         
     Qubole.configure(api_token=options.api_token,
                      api_url=options.api_url,
                      version=options.api_version,
-                     poll_interval=options.poll_interval)
+                     poll_interval=options.poll_interval,
+                     skip_ssl_cert_check=options.skip_ssl_cert_check)
                      
 
     if len(args) < 1:
@@ -197,7 +206,7 @@ def main():
         usage(optparser)
 
     cmdsuffix = "cmd"
-    cmdset = set([x + cmdsuffix for x in ["hive", "pig", "hadoop", "shell"]])
+    cmdset = set([x + cmdsuffix for x in ["hive", "pig", "hadoop", "shell", "dbexport"]])
 
 
     a0 = args.pop(0)
